from pyrustic import PROJECTS

TEXT = """
Pyrustic Open Ecosystem
=======================

This is a collection of lightweight Python projects that share the same policy.
The goal is to build and maintain a reliable, consistent, easy-to-use 
and relevant Python codebase for tech enthusiasts.

These projects cover various topics: automation, data persistence 
and exchange, GUI, themes, widgets, multithreading, markup, utilities, 
project management, et cetera.

https://pyrustic.github.io

Projects:
=========

"""


def main():
    cache = list()
    for key, value in PROJECTS.items():
        description, link = value
        item = "- {}: {}\n{}".format(key, description, link)
        cache.append(item)
    s = "\n\n".join(cache)
    print(TEXT + s)


if __name__ == "__main__":
    main()



import os.path

USER_HOME = os.path.expanduser("~")
PYRUSTIC_HOME = os.path.join(USER_HOME, "PyrusticHome")


PROJECTS = {"backstage": ("Three-speed scripting language and automation tool",
                          "https://github.com/pyrustic/backstage"),
            "buildver": ("Tool to build Python packages with built-in intuitive versioning mechanism",
                         "https://github.com/pyrustic/buildver"),
            "exn": ("Browse a dossier of exonotes",
                         "https://github.com/pyrustic/exn"),
            "exonote": ("Write and render rich, scriptable, and interactive notes",
                         "https://github.com/pyrustic/exonote"),
            "gaspium": ("Reference framework to build GASP apps",
                         "https://github.com/pyrustic/gaspium"),
            "hooking": ("Generic Hooking Mechanism for Python",
                         "https://github.com/pyrustic/hooking"),
            "jesth": ("Just Extract Sections Then Hack ! ",
                         "https://github.com/pyrustic/jesth"),
            "megawidget": ("Collection of megawidgets to build graphical user interfaces for Python apps",
                         "https://github.com/pyrustic/megawidget"),
            "menubar": ("Menubar",
                         "https://github.com/pyrustic/menubar"),
            "oscan": ("Scanner for hacking computer languages",
                         "https://github.com/pyrustic/oscan"),
            "peristyle": ("Peristyle",
                         "https://github.com/pyrustic/peristyle"),
            "probed": ("Probed collections for Python",
                         "https://github.com/pyrustic/probed"),
            "setupinit": ("Initialize Python projects",
                         "https://github.com/pyrustic/setupinit"),
            "shared": ("Triptych for data exchange and persistence",
                         "https://github.com/pyrustic/shared"),
            "subrun": ("Processes spawning in Python",
                         "https://github.com/pyrustic/subrun"),
            "suggestion": ("Democratizing auto-complete(suggest) for Python desktop applications",
                         "https://github.com/pyrustic/suggestion"),
            "threadom": ("Tkinter-compatible multithreading",
                         "https://github.com/pyrustic/threadom"),
            "tkutil": ("Utilities for Tkinter",
                         "https://github.com/pyrustic/tkutil"),
            "viewable": ("Python library to implement a GUI view with lifecycle",
                         "https://github.com/pyrustic/viewable"),
            "viewstack": ("Viewstack for Python GUI programming",
                         "https://github.com/pyrustic/viewstack")}
